import { API_ENDPOINTS } from "@/utils/api-config";

export const dynamic = "force-dynamic";

export async function GET() {
	try {
		// Rufe Jobs vom externen Backend ab
		const response = await fetch(API_ENDPOINTS.JOBS);
		
		if (!response.ok) {
			console.error(`Backend-Fehler: ${response.status} ${response.statusText}`);
			return new Response(JSON.stringify({ error: 'Backend nicht erreichbar' }), {
				status: 502,
				headers: { 'Content-Type': 'application/json' }
			});
		}
		
		const jobs = await response.json();
		return Response.json(jobs);
	} catch (error) {
		console.error('Fehler beim Abrufen der Jobs vom Backend:', error);
		return new Response(JSON.stringify({ error: 'Backend nicht erreichbar' }), {
			status: 500,
			headers: { 'Content-Type': 'application/json' }
		});
	}
}

export async function POST(request: Request) {
	try {
		const body = await request.json();
		
		// Sende Job-Erstellung an das externe Backend
		const response = await fetch(API_ENDPOINTS.JOBS, {
			method: 'POST',
			headers: {
				'Content-Type': 'application/json'
			},
			body: JSON.stringify(body)
		});
		
		if (!response.ok) {
			console.error(`Backend-Fehler: ${response.status} ${response.statusText}`);
			return new Response(JSON.stringify({ error: 'Backend nicht erreichbar' }), {
				status: 502,
				headers: { 'Content-Type': 'application/json' }
			});
		}
		
		const result = await response.json();
		return Response.json(result);
	} catch (error) {
		console.error('Fehler beim Erstellen des Jobs:', error);
		return new Response(JSON.stringify({ error: 'Fehler beim Erstellen des Jobs' }), {
			status: 500,
			headers: { 'Content-Type': 'application/json' }
		});
	}
}