import { github } from "@/server/auth/oauth";
import { OAUTH_CALLBACK_URL } from "@/utils/api-config";
import { generateState } from "arctic";
import { cookies } from "next/headers";

export const dynamic = "force-dynamic";

export async function GET(): Promise<Response> {
	const state = generateState();
	
	// Verwende die zentral definierte Callback-URL
	const url = await github.createAuthorizationURL(state, {
		scopes: ["user"],
		redirectURI: OAUTH_CALLBACK_URL,
	});
	const ONE_HOUR = 60 * 60;

	cookies().set("github_oauth_state", state, {
		path: "/",
		secure: false, //process.env.NODE_ENV === "production", -- can't be used until SSL certificate is provided by IT
		httpOnly: true,
		maxAge: ONE_HOUR,
		sameSite: "lax",
	});

	// Log zur Fehlersuche
	console.log(`GitHub OAuth redirect zu: ${url.toString()}`);
	console.log(`Verwendete Callback-URL: ${OAUTH_CALLBACK_URL}`);

	return Response.redirect(url);
}
